@@ -231,10 +231,10 @@ def _create_train_task(name: str,
     for k, v in mounts.items():
         if isinstance(v, list):
             resource_ids.extend([v_item.id for v_item in v])
-            train_params[k] = [f"${v_item.id}" for v_item in v]
+            train_params[k] = [f"\"${v_item.id}\"" for v_item in v]
         else:
             resource_ids.append(v.id)
-            train_params[k] = f"${v.id}"
+            train_params[k] = f"\"${v.id}\""
     train_task = TrainTask(
         name=name,
         project_id=project.id,
@@ -262,7 +262,7 @@ def quick_train(algorithm_id: Optional[str]=None,
                 dataset_dir: Optional[Union[str, Path]]=None,
                 dataset_archive: Optional[str]=None,
                 model_hyperparam_name: str="model",
-                model_id: Optional[str]=None,
+                model_id: Optional[Union[List[str], str]]=None,
                 pretrain_hyperparam_name: str="pretrain",
                 pretrain_task_id: Optional[Union[List[str], str]]=None,
                 project_id: Optional[str]=None,
@@ -412,10 +412,17 @@ def quick_train(algorithm_id: Optional[str]=None,
     resource_request = _format_resource_request(resource_request)
 
     # Remote odel
-    model = Model(id=model_id, load_detail=True) if model_id else None
+    if model_id is None:
+        model_id = []
+    elif not isinstance(model_id, list):
+        model_id = [model_id]
+    models = [
+        Model(id=_id, load_detail=True)
+        for _id in model_id
+    ]
 
     # Remote pretrain task results
-    if pretrain_task_id == None:
+    if pretrain_task_id is None:
         pretrain_task_id = []
     elif not isinstance(pretrain_task_id, list):
         pretrain_task_id = [pretrain_task_id]
@@ -464,8 +471,8 @@ def quick_train(algorithm_id: Optional[str]=None,
     mounts = {}
     if dset and dataset_hyperparam_name:
         mounts[dataset_hyperparam_name] = dset
-    if model and model_hyperparam_name:
-        mounts[model_hyperparam_name] = model
+    if models and model_hyperparam_name:
+        mounts[model_hyperparam_name] = models
     if pretrain_tasks and pretrain_hyperparam_name:
         mounts[pretrain_hyperparam_name] = [t.get_results_file() for t in pretrain_tasks]
 
