@@ -2,6 +2,7 @@ from __future__ import annotations
 from datetime import datetime
 import json
 from typing import Optional, Union
+import re
 
 from anylearn.utils.api import url_base, get_with_token, post_with_token
 from anylearn.utils.errors import AnyLearnException
@@ -63,7 +64,7 @@ class Algorithm(Resource):
     _fields = {
         # 资源创建/更新请求包体中必须包含且不能为空的字段
         'required': {
-            'create': ['name', 'filename', 'mirror_id', 'train_params'],
+            'create': ['name', 'filename', 'mirror_id'],
             'update': ['id', 'name'],
         },
         # 资源创建/更新请求包体中包含的所有字段
@@ -268,6 +269,13 @@ class Algorithm(Resource):
 
     def _payload_create(self):
         payload = super()._payload_create()
+        # Algorithm name verification
+        name_pattern = re.compile(r'[a-zA-Z0-9_.-]+$')
+        if not name_pattern.match(payload['name']):
+            raise AnyLearnException(
+                "Algorithm name should contain only alphanumeric, dash ('-'), "
+                "underscore ('_') and dot ('.') characters"
+            )
         payload['follows_anylearn_norm'] = int(payload['follows_anylearn_norm'])
         return self.__payload_algo_params_to_str(payload)
 
@@ -295,16 +303,18 @@ class Algorithm(Resource):
         """
         if not train_params:
             return
-        (self.__train_params, 
-         self.required_train_params, 
-         self.default_train_params) = self.__parse_json_params(train_params)
+        params = json.loads(train_params)
+        if params == None:
+            return
+        self.__train_params = params
+        (self.required_train_params,
+         self.default_train_params) = self.__parse_params(params)
 
-    def __parse_json_params(self, json_params):
-        params = json.loads(json_params)
+    def __parse_params(self, params):
         required_params = [p for p in params if 'default' not in p]
         default_params = {p['name']: p['default'] for p in params
                           if 'default' in p}
-        return params, required_params, default_params
+        return required_params, default_params
 
     @classmethod
     def get_user_custom_algorithm_by_name(cls, name: str):
