@@ -186,12 +186,25 @@ class TestAlgorithm(BaseTestCase):
         self.assertIsInstance(e, AnyLearnException)
         self.assertEqual(e.msg, "请求未能得到有效响应")
 
+    def test_create_algo_name_not_standard(self):
+        with self.assertRaises(AnyLearnException) as ctx:
+            algo = Algorithm(name="Test@ALGO/001", 
+                             filename="test.tar.gz",
+                             mirror_id="MIRR001")
+            algo.save()
+        e = ctx.exception
+        self.assertIsInstance(e, AnyLearnException)
+        self.assertEqual(
+            e.msg,
+            "Algorithm name should contain only alphanumeric, dash ('-'), underscore ('_') and dot ('.') characters"
+        )
+
     @responses.activate
     def test_create_algo_ok(self):
         responses.add(responses.POST, url=self._url("algorithm/add"),
                       json={'data': "ALGO001", 'message': "算法添加成功"},
                       status=200)
-        algo = Algorithm(name="TestALGO001", filename="test.tar.gz",
+        algo = Algorithm(name="Test-ALGO_00.1", filename="test.tar.gz",
                          train_params='[{"name": "test", "type": "int", "suggest": 1, "default": "0", "scope": "<0,1>"}]',
                          mirror_id="MIRR001")
         result = algo.save()
